==> igniteui-webcomponents-core-3.2.2.tgz: package/esm5/lib/WebTreeItemComponentEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebTreeItemDescriptionMetadata } from "./WebTreeItemDescriptionMetadata";
import { WebTreeItemComponentEventArgsDescription } from "./WebTreeItemComponentEventArgsDescription";
/**
 * @hidden
 */
var WebTreeItemComponentEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebTreeItemComponentEventArgsDescriptionMetadata, _super);
    function WebTreeItemComponentEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebTreeItemComponentEventArgsDescriptionMetadata.b = function (a) {
        if (WebTreeItemComponentEventArgsDescriptionMetadata.a == null) {
            WebTreeItemComponentEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebTreeItemComponentEventArgsDescriptionMetadata.c(WebTreeItemComponentEventArgsDescriptionMetadata.a);
        }
        if (a.g(WebTreeItemComponentEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(WebTreeItemComponentEventArgsDescriptionMetadata.a);
        WebTreeItemDescriptionMetadata.d(a);
    };
    WebTreeItemComponentEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:TreeItemComponentEventArgs");
        a.item("Detail", "ExportedType:WebTreeItem");
    };
    WebTreeItemComponentEventArgsDescriptionMetadata.d = function (a) {
        WebTreeItemComponentEventArgsDescriptionMetadata.b(a);
        a.u("WebTreeItemComponentEventArgs", function () { return new WebTreeItemComponentEventArgsDescription(); });
        a.t("WebTreeItemComponentEventArgs", WebTreeItemComponentEventArgsDescriptionMetadata.a);
    };
    WebTreeItemComponentEventArgsDescriptionMetadata.$t = markType(WebTreeItemComponentEventArgsDescriptionMetadata, 'WebTreeItemComponentEventArgsDescriptionMetadata');
    WebTreeItemComponentEventArgsDescriptionMetadata.a = null;
    return WebTreeItemComponentEventArgsDescriptionMetadata;
}(Base));
export { WebTreeItemComponentEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebTreeItemComponentEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebTreeItemDescriptionMetadata } from "./WebTreeItemDescriptionMetadata";
import { WebTreeItemComponentEventArgsDescription } from "./WebTreeItemComponentEventArgsDescription";
/**
 * @hidden
 */
var WebTreeItemComponentEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebTreeItemComponentEventArgsDescriptionMetadata, _super);
    function WebTreeItemComponentEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebTreeItemComponentEventArgsDescriptionMetadata.b = function (a) {
        if (WebTreeItemComponentEventArgsDescriptionMetadata.a == null) {
            WebTreeItemComponentEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebTreeItemComponentEventArgsDescriptionMetadata.c(WebTreeItemComponentEventArgsDescriptionMetadata.a);
        }
        if (a.j(WebTreeItemComponentEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebTreeItemComponentEventArgsDescriptionMetadata.a);
        WebTreeItemDescriptionMetadata.d(a);
    };
    WebTreeItemComponentEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:TreeItemComponentEventArgs");
        a.item("Detail", "ExportedType:WebTreeItem");
    };
    WebTreeItemComponentEventArgsDescriptionMetadata.d = function (a) {
        WebTreeItemComponentEventArgsDescriptionMetadata.b(a);
        a.aa("WebTreeItemComponentEventArgs", function () { return new WebTreeItemComponentEventArgsDescription(); });
        a.z("WebTreeItemComponentEventArgs", WebTreeItemComponentEventArgsDescriptionMetadata.a);
    };
    WebTreeItemComponentEventArgsDescriptionMetadata.$t = markType(WebTreeItemComponentEventArgsDescriptionMetadata, 'WebTreeItemComponentEventArgsDescriptionMetadata');
    WebTreeItemComponentEventArgsDescriptionMetadata.a = null;
    return WebTreeItemComponentEventArgsDescriptionMetadata;
}(Base));
export { WebTreeItemComponentEventArgsDescriptionMetadata };
